{% load i18n log %} {% get_admin_log 10 as admin_log for_user user %}

## {% translate 'Recent actions' %}

{% if not admin_log %}

{% translate 'None available' %}

{% else %}

{% for entry in admin_log %}
- {% if entry.is_deletion or not entry.get_admin_url %} {{ entry.object_repr }} {% else %} {{ entry.object_repr }} {% endif %}
  {% if entry.content_type %} {% filter capfirst %}{{ entry.content_type.name }}{% endfilter %} {% else %} {% translate 'Unknown content' %} {% endif %}
  {{ entry.action_time }}
{% endfor %}

{% endif %}